pub struct ExitFailure(/* private fields */);Expand description
The newtype wrapper around failure::Error
ⓘ
fn main() -> Result<(), ExitFailure> {
Ok(some_fn()?)
}
fn some_fn() -> Result<(), failure::Error> {
let error = Err(failure::err_msg("root cause failure"));
Ok(error.context("this is some context".to_string())?)
}Trait Implementations
Sourceimpl Debug for ExitFailure
Prints a list of causes for this Error, along with any backtrace
information collected by the Error (if RUST_BACKTRACE=1).
impl Debug for ExitFailure
Prints a list of causes for this Error, along with any backtrace information collected by the Error (if RUST_BACKTRACE=1).